@@ -87,7 +87,7 @@ gconf_tree_model_search_iter_foreach (GtkTreeModel *model, GtkTreePath *path,
 				/* We found the pattern in the final key name */
 				gedit_output_window_append_line (st->output_window, key, FALSE);
 				st->res++;
-				gconf_entry_free (entry);
+				gconf_entry_unref (entry);
 				/* After finding an entry continue the list to find other matches */
 				continue;
 			}
@@ -103,7 +103,7 @@ gconf_tree_model_search_iter_foreach (GtkTreeModel *model, GtkTreePath *path,
 			if (gconf_value != NULL && gconf_value->type == GCONF_VALUE_STRING)
 				gconf_string = gconf_value_get_string (gconf_value);
 			else {
-				gconf_entry_free (entry);
+				gconf_entry_unref (entry);
 				continue;
 			}
 
@@ -112,11 +112,11 @@ gconf_tree_model_search_iter_foreach (GtkTreeModel *model, GtkTreePath *path,
 				/* We found the pattern in the key value */
 				gedit_output_window_append_line (st->output_window, key, FALSE);
 				st->res++;
-				gconf_entry_free (entry);
+				gconf_entry_unref (entry);
 				continue;
 			}
 		}
-		gconf_entry_free (entry);
+		gconf_entry_unref (entry);
 	}
 
 	return FALSE;
@@ -141,7 +141,7 @@ gconf_tree_model_build_match_list (GConfTreeModel *tree_model, GeditOutputWindow
 
 	g_object_add_weak_pointer (st->searching, (gpointer)&st->searching);
 
-	if (!gtk_tree_model_get_iter_root (GTK_TREE_MODEL (tree_model), &iter_root)) {
+	if (!gtk_tree_model_get_iter_first (GTK_TREE_MODEL (tree_model), &iter_root)) {
 
 		/* Ugh, something is terribly wrong */
 		return 0;
